Django Premailer — django-premailer 0.1.0 documentation

# Django Premailer

Django template tag that turns CSS blocks into style attributes using premailer.

It supports Django 1.6+ for Python versions 2.7, 3.3, 3.4, 3.5 and pypy (where the Django version supports the Python version).

## Contents

- Installation
- Usage
- Developer Documentation
- Internal Module Reference

## License

This software is licensed under the MIT License. See the LICENSE.

## History

This package started out as a simple way to construct browser tests using YAML, written by Brenton Cleeland.

The focus of this fork is to allow the developer to write programmatic unit tests in the style of unittest.

Currently this fork does not contain any of the CSS selector style methods that were originally available as the focus has been on xpath only support until a more robust CSS selector toolkit can be provided.

## Thanks

- Special thanks to http://roi.com.au for supporting this project.
- Thanks to https://github.com/roverdotcom/django-inlinecss for initial inspiration.

## Author

Alex Hayes <alex@alution.com>